@@ -24,7 +24,7 @@ import pytz
 import simplejson as json
 
 # Local application imports
-from faraday_plugins.plugins.plugins_utils import its_cve, its_cwe
+from faraday_plugins.plugins.plugins_utils import its_cve, its_cwe, VulnerabilitySeverity
 
 logger = logging.getLogger("faraday").getChild(__name__)
 
@@ -41,6 +41,8 @@ class PluginBase:
         # an existent plugin with the same id.
         # TODO: Make script that list current ids.
         self.ignore_info = kwargs.get("ignore_info", False)
+        self.min_severity = kwargs.get("min_severity", None)
+        self.max_severity = kwargs.get("max_severity", None)
         self.hostname_resolution = kwargs.get("hostname_resolution", True)
         self.vuln_tag = kwargs.get("vuln_tag", None)
         self.host_tag = kwargs.get("host_tag", None)
@@ -172,34 +174,49 @@ class PluginBase:
         else:
             obj_uuid = self._service_cache[cache_id]
         return obj_uuid
+    
+    def _should_ignore_check(self, vuln):
+        # Ignore Info
+        if self.ignore_info and vuln['severity'] == 'info':
+            return True
+        
+        # Severity Range check
+        if self.min_severity and VulnerabilitySeverity[vuln['severity'].upper()].value < VulnerabilitySeverity[self.min_severity.upper()].value:
+            return True
+        if self.max_severity and VulnerabilitySeverity[vuln['severity'].upper()].value > VulnerabilitySeverity[self.max_severity.upper()].value:
+            return True
+        
+        return False
 
     def save_service_vuln_cache(self, host_id, service_id, vuln):
-        if self.ignore_info and vuln['severity'] == 'info':
+
+        if self._should_ignore_check(vuln):
             return None
+        
+        cache_id = self.get_service_vuln_cache_id(host_id, service_id, vuln)
+        if cache_id not in self._vulns_cache:
+            obj_uuid = self.save_cache(vuln)
+            service = self.get_from_cache(service_id)
+            service["vulnerabilities"].append(vuln)
+            self._vulns_cache[cache_id] = obj_uuid
         else:
-            cache_id = self.get_service_vuln_cache_id(host_id, service_id, vuln)
-            if cache_id not in self._vulns_cache:
-                obj_uuid = self.save_cache(vuln)
-                service = self.get_from_cache(service_id)
-                service["vulnerabilities"].append(vuln)
-                self._vulns_cache[cache_id] = obj_uuid
-            else:
-                obj_uuid = self._vulns_cache[cache_id]
-            return obj_uuid
+            obj_uuid = self._vulns_cache[cache_id]
+        return obj_uuid
 
     def save_host_vuln_cache(self, host_id, vuln):
-        if self.ignore_info and vuln['severity'] == 'info':
+
+        if self._should_ignore_check(vuln):
             return None
+        
+        cache_id = self.get_host_vuln_cache_id(host_id, vuln)
+        if cache_id not in self._vulns_cache:
+            obj_uuid = self.save_cache(vuln)
+            host = self.get_from_cache(host_id)
+            host["vulnerabilities"].append(vuln)
+            self._vulns_cache[cache_id] = obj_uuid
         else:
-            cache_id = self.get_host_vuln_cache_id(host_id, vuln)
-            if cache_id not in self._vulns_cache:
-                obj_uuid = self.save_cache(vuln)
-                host = self.get_from_cache(host_id)
-                host["vulnerabilities"].append(vuln)
-                self._vulns_cache[cache_id] = obj_uuid
-            else:
-                obj_uuid = self._vulns_cache[cache_id]
-            return obj_uuid
+            obj_uuid = self._vulns_cache[cache_id]
+        return obj_uuid
 
     @staticmethod
     def _get_dict_hash(d, keys):
@@ -348,7 +365,7 @@ class PluginBase:
                 self.logger.error(f"Error on delete file: ({filename}) [{e}]")
 
     def processReport(self, filepath: Path, user="faraday"):
-        if type(filepath) == str:  # TODO workaround for compatibility, remove in the future
+        if isinstance(filepath, str):  # TODO workaround for compatibility, remove in the future
             filepath = Path(filepath)
         if filepath.is_file():
             self.vulns_data["command"]["params"] = filepath.name if not self.ignore_info else f"{filepath.name} (Info ignored)"
@@ -442,7 +459,7 @@ class PluginBase:
                                severity="", resolution="", data="", external_id=None, run_date=None,
                                impact=None, custom_fields=None, status="", policyviolations=None,
                                easeofresolution=None, confirmed=False, tags=None, cve=None, cwe=None, cvss2=None,
-                               cvss3=None):
+                               cvss3=None, cvss4=None):
 
         ref = self.modify_refs_struct(ref)
         if status == "":
@@ -481,11 +498,14 @@ class PluginBase:
             cvss2 = {}
         if cvss3 is None:
             cvss3 = {}
+        if cvss4 is None:
+            cvss4 = {}
         vulnerability = {"name": name, "desc": desc, "severity": self.normalize_severity(severity), "refs": ref,
                          "external_id": external_id, "type": "Vulnerability", "resolution": resolution, "data": data,
                          "custom_fields": custom_fields, "status": status, "impact": impact,
                          "policyviolations": policyviolations, "cve":  cve, "cvss3": cvss3, "cvss2": cvss2,
-                         "confirmed": confirmed, "easeofresolution": easeofresolution, "tags": tags, "cwe": cwe
+                         "confirmed": confirmed, "easeofresolution": easeofresolution, "tags": tags, "cwe": cwe,
+                         "cvss4": cvss4
                          }
         if run_date:
             vulnerability["run_date"] = self.get_utctimestamp(run_date)
@@ -496,7 +516,7 @@ class PluginBase:
                                   ref=None, severity="", resolution="", data="", external_id=None, run_date=None,
                                   custom_fields=None, policyviolations=None, impact=None, status="",
                                   confirmed=False, easeofresolution=None, tags=None, cve=None, cwe=None, cvss2=None,
-                                  cvss3=None):
+                                  cvss3=None, cvss4=None):
         ref = self.modify_refs_struct(ref)
         if status == "":
             status = "open"
@@ -534,11 +554,14 @@ class PluginBase:
             cvss2 = {}
         if cvss3 is None:
             cvss3 = {}
+        if cvss4 is None:
+            cvss4 = {}
         vulnerability = {"name": name, "desc": desc, "severity": self.normalize_severity(severity), "refs": ref,
                          "external_id": external_id, "type": "Vulnerability", "resolution": resolution, "data": data,
                          "custom_fields": custom_fields, "status": status, "impact": impact,
                          "policyviolations": policyviolations, "cve": cve, "cvss3": cvss3, "cvss2": cvss2,
-                         "easeofresolution": easeofresolution, "confirmed": confirmed, "tags": tags, "cwe": cwe
+                         "easeofresolution": easeofresolution, "confirmed": confirmed, "tags": tags, "cwe": cwe,
+                         "cvss4": cvss4
                          }
         if run_date:
             vulnerability["run_date"] = self.get_utctimestamp(run_date)
@@ -552,7 +575,7 @@ class PluginBase:
                                      params="", query="", category="", data="", external_id=None,
                                      confirmed=False, status="", easeofresolution=None, impact=None,
                                      policyviolations=None, status_code=None, custom_fields=None, run_date=None,
-                                     tags=None, cve=None, cvss2=None, cvss3=None, cwe=None):
+                                     tags=None, cve=None, cvss2=None, cvss3=None, cvss4=None, cwe=None):
         if params is None:
             params = ""
         if method is None:
@@ -606,6 +629,8 @@ class PluginBase:
             cvss2 = {}
         if cvss3 is None:
             cvss3 = {}
+        if cvss4 is None:
+            cvss4 = {}
         vulnerability = {"name": name, "desc": desc, "severity": self.normalize_severity(severity), "refs": ref,
                          "external_id": external_id, "type": "VulnerabilityWeb", "resolution": resolution,
                          "data": data, "website": website, "path": path, "request": request, "response": response,
@@ -613,7 +638,7 @@ class PluginBase:
                          "confirmed": confirmed, "status": status, "easeofresolution": easeofresolution,
                          "impact": impact, "policyviolations": policyviolations, "cve": cve,  "cvss3": cvss3,
                          "cvss2": cvss2, "status_code": status_code, "custom_fields": custom_fields, "tags": tags,
-                         "cwe": cwe}
+                         "cwe": cwe, "cvss4": cvss4}
         if run_date:
             vulnerability["run_date"] = self.get_utctimestamp(run_date)
         vulnerability_id = self.save_service_vuln_cache(host_id, service_id, vulnerability)
@@ -705,9 +730,9 @@ class PluginByExtension(PluginBase):
 
     def report_belongs_to(self, extension="", **kwargs):
         match = False
-        if type(self.extension) == str:
+        if isinstance(self.extension, str):
             match = (self.extension == extension)
-        elif type(self.extension) == list:
+        elif isinstance(self.extension, list):
             match = (extension in self.extension)
         self.logger.debug(f"Extension Match: [{extension} =/in {self.extension}] -> {match}")
         return match
@@ -725,9 +750,9 @@ class PluginXMLFormat(PluginByExtension):
     def report_belongs_to(self, main_tag="", main_tag_attributes={}, **kwargs):
         match = False
         if super().report_belongs_to(**kwargs):
-            if type(self.identifier_tag) == str:
+            if isinstance(self.identifier_tag, str):
                 match = (main_tag == self.identifier_tag)
-            elif type(self.identifier_tag) == list:
+            elif isinstance(self.identifier_tag, list):
                 match = (main_tag in self.identifier_tag)
             if self.identifier_tag_attributes:
                 match = self.identifier_tag_attributes.issubset(main_tag_attributes)
